@@ -23,7 +23,7 @@ VARIABLES = [
     TextVar("ARCH", Backtick("dpkg", "--print-architecture"),
             help="Architecture of the target distribution"),
     TextVar("CODENAME", Backtick("lsb_release", "--short", "--codename"), cmdline="--dist",
-            help="distribution name (etch, lenny, wheezy, jessie, ..., sid)"),
+            help="distribution name (jessie, stretch, buster, bullseye, ..., sid)"),
     TextVar("DI_CODENAME", "{CODENAME}",
             help="distribution name for debian-installer"),
     TextVar("DISKTYPE", "CD",
@@ -50,7 +50,7 @@ VARIABLES = [
             help="list of files included on CD's local package repository"),
     ListVar("build_profiles", cmdline=("--build-profiles", "-b"),
             help="profiles only used while building the CD"),
-    ListVar("mirror_tools", ["wget", "reprepro"], cmdline="--mirror-tools",
+    ListVar("mirror_tools", ["download", "reprepro"], cmdline="--mirror-tools",
             help="list the mirror tools to be used"),
     ListVar("build_tools", "debian-cd", cmdline="--build-tools",
             help="list the build tools to be used"),
@@ -69,8 +69,8 @@ VARIABLES = [
             help="distribution components to use when getting packages from debian_mirror_extra"),
     ListVar("ARCHES", "{ARCH}",
             help="all the architectures that will be present in the built ISO"),
-    TextVar("wget_debian_mirror", "{debian_mirror}",
-            help="Debian mirror base URL that will be used when invoking wget"),
+    TextVar("files_debian_mirror", "{debian_mirror}",
+            help="Debian mirror base URL that will be used when downloading files"),
     TextVar("simple_cdd_preseed", "preseed/file=/cdrom/simple-cdd/default.preseed",
             help="kernel command line parameter to enable simple-cdd debconf preseeding"),
     PathVar("TASK", ["{simple_cdd_temp}", "simple-cdd.task"],
@@ -90,7 +90,7 @@ VARIABLES = [
             help="working directory for debian-cd"),
     PathVar("MIRROR", "{simple_cdd_mirror}",
             help="directory where the local mirror is stored"),
-    TextVar("DEBVERSION", Backtick("lsb_release", "--short", "--release"),
+    TextVar("DEBVERSION", None,
             help="Numeric version of Debian release."),
     TextVar("OFFICIAL", "Unofficial",
             help="TODO: passed as is to debian-cd"),
